@@ -2,7 +2,7 @@ __all__ = ["CoordCalculator"]
 
 import os
 import time
-from typing import Optional, Sequence, Tuple, TypeVar, Union
+from typing import List, Optional, Tuple, TypeVar, Union
 
 import astropy.constants as const
 import astropy.units as u
@@ -83,6 +83,7 @@ class CoordCalculator:
         self,
         location: EarthLocation,
         pointing_param_path: Optional[os.PathLike] = None,
+        pointing_model: Optional[str] = None,
         *,
         pressure: Optional[u.Quantity] = None,
         temperature: Optional[u.Quantity] = None,
@@ -106,7 +107,9 @@ class CoordCalculator:
             self.obswl = const.c / obsfreq  # type: ignore
 
         if pointing_param_path is not None:
-            self.pointing_error_corrector = PointingError.from_file(pointing_param_path)
+            self.pointing_error_corrector = PointingError.from_file(
+                pointing_param_path, pointing_model
+            )
         else:
             self.logger.warning("Pointing error correction is disabled.")
             dummy = PointingError()
@@ -154,7 +157,7 @@ class CoordCalculator:
         self,
         name: str,
         obstime: Optional[Union[Number, Time]] = None,
-    ) -> Tuple[u.Quantity, u.Quantity, Sequence[float]]:
+    ) -> Tuple[u.Quantity, u.Quantity, List[float]]:
         """天体名から地平座標 az, el(alt) を取得する
 
         Parameters
@@ -191,7 +194,7 @@ class CoordCalculator:
         *,
         unit: Optional[UnitType] = None,
         obstime: Optional[Union[Number, Time]] = None,
-    ) -> Tuple[u.Quantity, u.Quantity, Sequence[float]]:
+    ) -> Tuple[u.Quantity, u.Quantity, List[float]]:
         """Get horizontal coordinate from longitude and latitude in arbitrary frame.
 
         Parameters
