@@ -1,8 +1,5 @@
 """Define and handle parameters."""
 
-# Alias
 from .obsparam import *  # noqa: F401, F403
-from .pointing_error import *  # noqa: F401, F403
-
-# Subpackage
 from .parser import *  # noqa: F401, F403
+from .pointing_error import PointingError  # noqa: F401
